<?php

namespace Litepie\Event\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Event\Http\Requests\BusinessDirectoryRequest;
use Litepie\Event\Interfaces\BusinessDirectoryRepositoryInterface;
use Litepie\Event\Models\BusinessDirectory;
use Litepie\Event\Forms\BusinessDirectory as Form;

/**
 * APIController  class for business_directory.
 */
class BusinessDirectoryAPIController extends BaseController
{

    /**
     * Initialize business_directory resource controller.
     *
     * @param type BusinessDirectoryRepositoryInterface $business_directory
     *
     * @return null
     */
    public function __construct(BusinessDirectoryRepositoryInterface $business_directory)
    {
        parent::__construct();
        $this->repository = $business_directory;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Event\Repositories\Criteria\BusinessDirectoryResourceCriteria::class);
    }

    /**
     * Display a list of business_directory.
     *
     * @return Response
     */
    public function index(BusinessDirectoryRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Event\Repositories\Presenter\BusinessDirectoryPresenter::class)
            ->paginate();
    }

    /**
     * Display business_directory.
     *
     * @param Request $request
     * @param Model   $business_directory
     *
     * @return Response
     */
    public function show(BusinessDirectoryRequest $request, BusinessDirectory $business_directory)
    {
        return $business_directory->setPresenter(\Litepie\Event\Repositories\Presenter\BusinessDirectoryListPresenter::class);
        ;
    }

    /**
     * Create new business_directory.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BusinessDirectoryRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('event::business_directory.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('event/business_directory/' . $business_directory->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/business_directory');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the business_directory.
     *
     * @param Request $request
     * @param Model   $business_directory
     *
     * @return Response
     */
    public function update(BusinessDirectoryRequest $request, BusinessDirectory $business_directory)
    {
        try {
            $data = $request->all();

            $business_directory->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('event::business_directory.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('event/business_directory/' . $business_directory->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/business_directory/' . $business_directory->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the business_directory.
     *
     * @param Model   $business_directory
     *
     * @return Response
     */
    public function destroy(BusinessDirectoryRequest $request, BusinessDirectory $business_directory)
    {
        try {
            $business_directory->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('event::business_directory.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('event/business_directory/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/business_directory/' . $business_directory->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
