<?php

namespace Litepie\Event\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Event\Http\Requests\EventRequest;
use Litepie\Event\Interfaces\EventRepositoryInterface;
use Litepie\Event\Models\Event;
use Litepie\Event\Forms\Event as Form;

/**
 * APIController  class for event.
 */
class EventAPIController extends BaseController
{

    /**
     * Initialize event resource controller.
     *
     * @param type EventRepositoryInterface $event
     *
     * @return null
     */
    public function __construct(EventRepositoryInterface $event)
    {
        parent::__construct();
        $this->repository = $event;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Event\Repositories\Criteria\EventResourceCriteria::class);
    }

    /**
     * Display a list of event.
     *
     * @return Response
     */
    public function index(EventRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Event\Repositories\Presenter\EventPresenter::class)
            ->paginate();
    }

    /**
     * Display event.
     *
     * @param Request $request
     * @param Model   $event
     *
     * @return Response
     */
    public function show(EventRequest $request, Event $event)
    {
        return $event->setPresenter(\Litepie\Event\Repositories\Presenter\EventListPresenter::class);
        ;
    }

    /**
     * Create new event.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EventRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('event::event.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('event/event/' . $event->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/event');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the event.
     *
     * @param Request $request
     * @param Model   $event
     *
     * @return Response
     */
    public function update(EventRequest $request, Event $event)
    {
        try {
            $data = $request->all();

            $event->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('event::event.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('event/event/' . $event->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/event/' . $event->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the event.
     *
     * @param Model   $event
     *
     * @return Response
     */
    public function destroy(EventRequest $request, Event $event)
    {
        try {
            $event->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('event::event.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('event/event/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/event/' . $event->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
