<?php

namespace Litepie\Event\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepie\Event\Interfaces\GalleryRepositoryInterface;

class GalleryPublicController extends BaseController
{
    // use GalleryWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepie\Gallery\Interfaces\GalleryRepositoryInterface $gallery
     *
     * @return type
     */
    public function __construct(GalleryRepositoryInterface $gallery)
    {
        $this->repository = $gallery;
        parent::__construct();
    }

    /**
     * Show gallery's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $galleries = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('event::gallery.names'))
            ->view('event::public.gallery.index')
            ->data(compact('galleries'))
            ->output();
    }


    /**
     * Show gallery.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $gallery = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($gallery->name . trans('event::gallery.name'))
            ->view('event::public.gallery.show')
            ->data(compact('gallery'))
            ->output();
    }

}
