<?php

namespace Litepie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Event\Models\BusinessDirectory;

class BusinessDirectoryPolicy
{

    /**
     * Determine if the given user can view the business_directory.
     *
     * @param UserPolicy $user
     * @param BusinessDirectory $business_directory
     *
     * @return bool
     */
    public function view(UserPolicy $user, BusinessDirectory $business_directory)
    {
        if ($user->canDo('event.business_directory.view') && $user->isAdmin()) {
            return true;
        }

        return $business_directory->user_id == user_id() && $business_directory->user_type == user_type();
    }

    /**
     * Determine if the given user can create a business_directory.
     *
     * @param UserPolicy $user
     * @param BusinessDirectory $business_directory
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.business_directory.create');
    }

    /**
     * Determine if the given user can update the given business_directory.
     *
     * @param UserPolicy $user
     * @param BusinessDirectory $business_directory
     *
     * @return bool
     */
    public function update(UserPolicy $user, BusinessDirectory $business_directory)
    {
        if ($user->canDo('event.business_directory.edit') && $user->isAdmin()) {
            return true;
        }

        return $business_directory->user_id == user_id() && $business_directory->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given business_directory.
     *
     * @param UserPolicy $user
     * @param BusinessDirectory $business_directory
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BusinessDirectory $business_directory)
    {
        return $business_directory->user_id == user_id() && $business_directory->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given business_directory.
     *
     * @param UserPolicy $user
     * @param BusinessDirectory $business_directory
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BusinessDirectory $business_directory)
    {
        if ($user->canDo('event.business_directory.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given business_directory.
     *
     * @param UserPolicy $user
     * @param BusinessDirectory $business_directory
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BusinessDirectory $business_directory)
    {
        if ($user->canDo('event.business_directory.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
