<?php

namespace Litepie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Event\Models\Program;

class ProgramPolicy
{

    /**
     * Determine if the given user can view the program.
     *
     * @param UserPolicy $user
     * @param Program $program
     *
     * @return bool
     */
    public function view(UserPolicy $user, Program $program)
    {
        if ($user->canDo('event.program.view') && $user->isAdmin()) {
            return true;
        }

        return $program->user_id == user_id() && $program->user_type == user_type();
    }

    /**
     * Determine if the given user can create a program.
     *
     * @param UserPolicy $user
     * @param Program $program
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.program.create');
    }

    /**
     * Determine if the given user can update the given program.
     *
     * @param UserPolicy $user
     * @param Program $program
     *
     * @return bool
     */
    public function update(UserPolicy $user, Program $program)
    {
        if ($user->canDo('event.program.edit') && $user->isAdmin()) {
            return true;
        }

        return $program->user_id == user_id() && $program->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given program.
     *
     * @param UserPolicy $user
     * @param Program $program
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Program $program)
    {
        return $program->user_id == user_id() && $program->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given program.
     *
     * @param UserPolicy $user
     * @param Program $program
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Program $program)
    {
        if ($user->canDo('event.program.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given program.
     *
     * @param UserPolicy $user
     * @param Program $program
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Program $program)
    {
        if ($user->canDo('event.program.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
