<?php

namespace Litepie\Event\Providers;

use Illuminate\Support\ServiceProvider;

class EventServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'event');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'event');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerEvent();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerEvent()
    {
        $this->app->bind('event', function($app) {
            return new Event($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Event', 'Lavalite\Event\Facades\Event');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litepie.event', function ($app) {
            return $this->app->make('Litepie\Event\Event');
        });

        // Bind Event to repository
        $this->app->bind(
            'Litepie\Event\Interfaces\EventRepositoryInterface',
            \Litepie\Event\Repositories\Eloquent\EventRepository::class
        );
        // Bind Program to repository
        $this->app->bind(
            'Litepie\Event\Interfaces\ProgramRepositoryInterface',
            \Litepie\Event\Repositories\Eloquent\ProgramRepository::class
        );
        // Bind BusinessDirectory to repository
        $this->app->bind(
            'Litepie\Event\Interfaces\BusinessDirectoryRepositoryInterface',
            \Litepie\Event\Repositories\Eloquent\BusinessDirectoryRepository::class
        );
        // Bind Gallery to repository
        $this->app->bind(
            'Litepie\Event\Interfaces\GalleryRepositoryInterface',
            \Litepie\Event\Repositories\Eloquent\GalleryRepository::class
        );

        $this->app->register(\Litepie\Event\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepie\Event\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and event's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepie.event'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeEvent::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepie.event'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepie/event.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/event')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/event')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
