<?php

namespace Litepie\Event\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litepie\Event\Models\Event;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litepie\Event\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/event/event/*')) {
            Route::bind('event', function ($event) {
                $eventrepo = $this->app->make('Litepie\Event\Interfaces\EventRepositoryInterface');
                return $eventrepo->findorNew($event);
            });
        }

        if (Request::is('*/event/program/*')) {
            Route::bind('program', function ($program) {
                $programrepo = $this->app->make('Litepie\Event\Interfaces\ProgramRepositoryInterface');
                return $programrepo->findorNew($program);
            });
        }

        if (Request::is('*/event/business_directory/*')) {
            Route::bind('business_directory', function ($business_directory) {
                $business_directoryrepo = $this->app->make('Litepie\Event\Interfaces\BusinessDirectoryRepositoryInterface');
                return $business_directoryrepo->findorNew($business_directory);
            });
        }

        if (Request::is('*/event/gallery/*')) {
            Route::bind('gallery', function ($gallery) {
                $galleryrepo = $this->app->make('Litepie\Event\Interfaces\GalleryRepositoryInterface');
                return $galleryrepo->findorNew($gallery);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
